@@ -1,7 +1,13 @@
-from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
+# Since Plone4.3 ViewPageTemplateFile moved to zope.browserpage
+try:
+    from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile
+except:
+    from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
+
 from z3c.rml.rml2pdf import parseString
 from Products.Five.browser import BrowserView
 
+
 class PrintSurveyView(BrowserView):
     """A printable view of a survey, rendered as a pdf"""
 
