@@ -10,13 +10,13 @@ except ImportError:
 from BTrees.OOBTree import OOBTree
 from persistent.mapping import PersistentMapping
 
-from Products.Archetypes.atapi import *
 from Products.ATContentTypes.content.base import ATCTContent
+from Products.CMFCore import permissions
 from Products.CMFCore.utils import getToolByName
 
-from Products.PloneSurvey import permissions
 from Products.PloneSurvey import PloneSurveyMessageFactory as _
 
+
 class BaseQuestion(ATCTContent):
     """Base class for survey questions"""
     immediate_view = "base_edit"
@@ -29,17 +29,20 @@ class BaseQuestion(ATCTContent):
     security = ClassSecurityInfo()
 
     security.declareProtected(permissions.ModifyPortalContent, 'reset')
+
     def reset(self):
         """Remove answers for all users."""
         self.answers = OOBTree()
 
     security.declareProtected(permissions.ModifyPortalContent, 'resetForUser')
+
     def resetForUser(self, userid):
         """Remove answer for a single user"""
-        if self.answers.has_key(userid):
+        if userid in self.answers:
             del self.answers[userid]
 
     security.declareProtected(permissions.View, 'addAnswer')
+
     def addAnswer(self, value, comments=""):
         """Add an answer and optional comments for a user.
         This method protects _addAnswer from anonymous users specifying a
@@ -56,8 +59,11 @@ class BaseQuestion(ATCTContent):
             elif getattr(ob, '_isPortalRoot', False):
                 raise Exception("Could not find a parent Survey.")
         portal_membership = getToolByName(self, 'portal_membership')
-        if portal_membership.isAnonymousUser() and not survey.getAllowAnonymous():
-            raise Unauthorized, ("This survey is not available to anonymous users.")
+        if portal_membership.isAnonymousUser() \
+           and not survey.getAllowAnonymous():
+            raise Unauthorized(
+                "This survey is not available to anonymous users."
+            )
         userid = self.getSurveyId()
         # Call the real method for storing the answer for this user.
         return self._addAnswer(userid, value, comments)
@@ -69,12 +75,13 @@ class BaseQuestion(ATCTContent):
         # answer can be supplied.
         # XXX this causes problem when survey fails validation
         # will also cause problem with save function
-##        if self.answers.has_key(userid):
-##            # XXX Should this get raised?  If so, a more appropriate
-##            # exception is probably in order.
-##            msg = "User '%s' has already answered this question. Reset the original response to supply a new answer."
-##            raise Exception(msg % userid)
-##        else:
+#        if self.answers.has_key(userid):
+#            # XXX Should this get raised?  If so, a more appropriate
+#            # exception is probably in order.
+#            msg = "User '%s' has already answered this question.
+#                   Reset the original response to supply a new answer."
+#            raise Exception(msg % userid)
+#        else:
         self.answers[userid] = PersistentMapping(value=value,
                                                  comments=comments)
         if not isinstance(self.answers, (PersistentMapping, OOBTree)):
@@ -83,6 +90,7 @@ class BaseQuestion(ATCTContent):
             self.answers._p_changed = 1
 
     security.declareProtected(permissions.View, 'getAnswerFor')
+
     def getAnswerFor(self, userid):
         """Get a specific user's answer"""
         answer = self.answers.get(userid, {}).get('value', None)
@@ -96,11 +104,13 @@ class BaseQuestion(ATCTContent):
         return answer
 
     security.declareProtected(permissions.View, 'getCommentsFor')
+
     def getCommentsFor(self, userid):
         """Get a specific user's comments"""
         return self.answers.get(userid, {}).get('comments', None)
 
     security.declareProtected(permissions.View, 'getComments')
+
     def getComments(self):
         """Return a userid, comments mapping"""
         mlist = []
@@ -112,28 +122,31 @@ class BaseQuestion(ATCTContent):
         return mlist
 
     security.declareProtected(permissions.View, 'getNumberOfRespondents')
+
     def getNumberOfRespondents(self):
         return len(self.answers.keys())
 
     security.declarePrivate('_get_yes_no_default')
+
     def _get_yes_no_default(self):
         foo = (_(u'Yes'), _(u'No'))
-        translation_service = getToolByName(self,'translation_service')
+        translation_service = getToolByName(self, 'translation_service')
         return (translation_service.utranslate(domain='plonesurvey',
-                                             msgid=u'Yes',
-                                             context=self),
+                                               msgid=u'Yes',
+                                               context=self),
                 translation_service.utranslate(domain='plonesurvey',
-                                             msgid=u'No',
-                                             context=self),
-                )
+                                               msgid=u'No',
+                                               context=self), )
 
     security.declarePrivate('_get_commentLabel_default')
+
     def _get_commentLabel_default(self):
-        foo = _(u'commentLabelDefault', default=u"Comment - mandatory if \"no\"")
-        translation_service = getToolByName(self,'translation_service')
-        return translation_service.utranslate(domain='plonesurvey',
-                                              msgid=u'commentLabelDefault',
-                                              default=u'Comment - mandatory if "no"',
-                                              context=self)
+        foo = _(u'commentLabelDefault',
+                default=u"Comment - mandatory if \"no\"")
+        translation_service = getToolByName(self, 'translation_service')
+        return translation_service.utranslate(
+            domain='plonesurvey',
+            msgid=u'commentLabelDefault',
+            default=u'Comment - mandatory if "no"', context=self)
 
 InitializeClass(BaseQuestion)
