@@ -1,20 +1,19 @@
-import string
 from AccessControl import ClassSecurityInfo
 from BTrees.OOBTree import OOBTree
 
-from Products.Archetypes.atapi import *
+from Products.Archetypes.atapi import IntDisplayList
 from Products.ATContentTypes.content.base import ATCTOrderedFolder
 from Products.ATContentTypes.content.base import registerATCT
-from Products.CMFCore.utils import getToolByName
+from Products.CMFCore import permissions
 from Products.CMFPlone.utils import safe_unicode
 
-from Products.PloneSurvey import permissions
 from Products.PloneSurvey.config import LIKERT_OPTIONS_MAP
 from Products.PloneSurvey.config import PROJECTNAME
 from Products.PloneSurvey.content.BaseQuestion import BaseQuestion
 
 from schemata import SurveyMatrixSchema
 
+
 class SurveyMatrix(ATCTOrderedFolder, BaseQuestion):
     """A matrix of questions within a survey"""
     schema = SurveyMatrixSchema
@@ -28,6 +27,7 @@ class SurveyMatrix(ATCTOrderedFolder, BaseQuestion):
     answers = OOBTree()
 
     security.declareProtected(permissions.View, 'validateAnswer')
+
     def validateAnswer(self, form, state):
         """Validate the question"""
         matrix_questions = self.getQuestions()
@@ -35,9 +35,10 @@ class SurveyMatrix(ATCTOrderedFolder, BaseQuestion):
         for matrix_q in matrix_questions:
             matrix_qid = str(self.getId()) + '-' + str(matrix_q.getId())
             value = form.get(matrix_qid, '')
-            error_value = matrix_q.validateAnswer(value,state)
+            error_value = matrix_q.validateAnswer(value, state)
             if error_value:
-                error_string = error_string + ' ' + str(matrix_q.title_or_id()) + ','
+                error_string = error_string + ' ' + \
+                    str(matrix_q.title_or_id()) + ','
         if error_string != '':
             error_string = safe_unicode(error_string[:-1])
             error_msg = self.translate(
@@ -47,16 +48,19 @@ class SurveyMatrix(ATCTOrderedFolder, BaseQuestion):
             state.setError(self.getId(), "%s %s" % (error_msg, error_string))
 
     security.declarePublic('canSetDefaultPage')
+
     def canSetDefaultPage(self):
         """Doesn't make sense for surveys to allow alternate views"""
         return False
 
     security.declarePublic('canConstrainTypes')
+
     def canConstrainTypes(self):
         """Should not be able to add non survey types"""
         return False
 
     security.declareProtected(permissions.View, 'getRequired')
+
     def getRequired(self):
         """Return 1 or 0 depending on if a null value exists"""
         if self.getNullValue():
@@ -65,6 +69,7 @@ class SurveyMatrix(ATCTOrderedFolder, BaseQuestion):
             return 1
 
     security.declareProtected(permissions.View, 'getQuestionOptions')
+
     def getQuestionOptions(self):
         """Return the options for this question"""
         if self.getLikertOptions():
@@ -82,12 +87,11 @@ class SurveyMatrix(ATCTOrderedFolder, BaseQuestion):
         return self.getAnswerOptions()
 
     security.declareProtected(permissions.View, 'getQuestions')
+
     def getQuestions(self):
         """Return the questions for this part of the survey"""
         questions = self.getFolderContents(
-            contentFilter={'portal_type':[
-                'Survey Matrix Question',
-                ]},
+            contentFilter={'portal_type': ['Survey Matrix Question', ]},
             full_objects=True)
         return questions
 
