@@ -1,17 +1,19 @@
 from AccessControl import ClassSecurityInfo
 from zope.interface import implements
 
-from Products.Archetypes.atapi import *
+from Products.Archetypes.atapi import IntDisplayList
 from Products.ATContentTypes.content.base import registerATCT
+from Products.CMFCore import permissions
 
-from Products.PloneSurvey import permissions
 from Products.PloneSurvey.config import LIKERT_OPTIONS_MAP
 from Products.PloneSurvey.config import PROJECTNAME
-from Products.PloneSurvey.interfaces import IPloneSurveyQuestion
+from Products.PloneSurvey.interfaces.survey_question \
+    import IPloneSurveyQuestion
 
 from BaseQuestion import BaseQuestion
 from schemata import SurveySelectQuestionSchema
 
+
 class SurveySelectQuestion(BaseQuestion):
     """A question with select vocab within a survey"""
     schema = SurveySelectQuestionSchema
@@ -23,6 +25,7 @@ class SurveySelectQuestion(BaseQuestion):
     security = ClassSecurityInfo()
 
     security.declareProtected(permissions.View, 'validateAnswer')
+
     def validateAnswer(self, value, comments, state):
         """Validate the question"""
         validates = True
@@ -37,33 +40,38 @@ class SurveySelectQuestion(BaseQuestion):
                 if value in self.getQuestionOptions():
                     self.addAnswer(value, comments)
                 else:
-                    state.setError(self.getId(), "This is not one of the answer options")
-            else: # value is a list
+                    state.setError(self.getId(),
+                                   "This is not one of the answer options")
+            else:  # value is a list
                 if self.getLikertOptions():
                     new_value = []
                     for item in value:
                         try:
                             item = int(item)
                         except ValueError:
-                            state.setError(self.getId(), "This is not an integer")
+                            state.setError(self.getId(),
+                                           "This is not an integer")
                             return
                         else:
                             new_value.append(item)
                     value = new_value
                 for item_value in value:
-                    if not item_value in self.getQuestionOptions():
+                    if item_value not in self.getQuestionOptions():
                         validates = False
                 if not validates:
-                        #state.setError(self.getId(), "This is not one of the answer options-2")
-                        state.setError(self.getId(), str(value) + str(self.getQuestionOptions()))
+                        state.setError(
+                            self.getId(),
+                            str(value) + str(self.getQuestionOptions()))
                 else:
                     self.addAnswer(value, comments)
         elif comments:
-            # XXX something more intelligent needs to be done here, and if neither value or comments is
+            # XXX something more intelligent needs to be done here,
+            # and if neither value or comments is
             # provided, then None is stored instead of empty string
             self.addAnswer(value, comments)
 
     security.declareProtected(permissions.View, 'getRequired')
+
     def getRequired(self):
         """Return 1 or 0 depending on if a null value exists"""
         if self.getNullValue():
@@ -72,6 +80,7 @@ class SurveySelectQuestion(BaseQuestion):
             return 1
 
     security.declareProtected(permissions.View, 'getQuestionOptions')
+
     def getQuestionOptions(self):
         """Return the options for this question"""
         if self.getLikertOptions():
@@ -89,6 +98,7 @@ class SurveySelectQuestion(BaseQuestion):
         return self.getAnswerOptions()
 
     security.declareProtected(permissions.View, 'getAggregateAnswers')
+
     def getAggregateAnswers(self):
         """Return a mapping of aggregrate answer values,
         suitable for a histogram"""
@@ -99,7 +109,7 @@ class SurveySelectQuestion(BaseQuestion):
         for option in options:
             aggregate_answers[option] = 0
         for k, answer in self.answers.items():
-            if answer['value']:
+            if answer['value'] or answer['value'] >= 0:
                 if isinstance(answer['value'], str) or isinstance(answer['value'], int):
                     try:
                         aggregate_answers[answer['value']] += 1
@@ -114,16 +124,17 @@ class SurveySelectQuestion(BaseQuestion):
         return aggregate_answers
 
     security.declareProtected(permissions.View, 'getPercentageAnswers')
+
     def getPercentageAnswers(self):
         """Return a mapping of aggregrate answer values,
         suitable for a barchart"""
         max = 0
         aggregate_answers = self.getAggregateAnswers()
-        for k,v in aggregate_answers.items():
+        for k, v in aggregate_answers.items():
             if v > max:
                 max = v
         pct_aggregate_answers = {}
-        for k,v in aggregate_answers.items():
+        for k, v in aggregate_answers.items():
             if v == 0:
                 value = 0
             else:
@@ -132,14 +143,15 @@ class SurveySelectQuestion(BaseQuestion):
         return pct_aggregate_answers
 
     security.declareProtected(permissions.View, 'getPercentages')
+
     def getPercentages(self):
         """Return a mapping of percentages for each answer"""
         total = 0
         aggregate_answers = self.getAggregateAnswers()
-        for k,v in aggregate_answers.items():
+        for k, v in aggregate_answers.items():
             total = v + total
         pct_answers = {}
-        for k,v in aggregate_answers.items():
+        for k, v in aggregate_answers.items():
             if v == 0:
                 value = 0
             else:
